@@ -22,7 +22,8 @@ class SpecLoader:
     :param beam_shape: Beam shape approximation. Either `'box'` or `'gauss'` (default).
     :param normalize_to: To what intensity value the curve is normalized to after footprint correction. Either
     `'first'` or `'max'` (default).
-
+    :param attenuator_column: Optional column name of the attenuator values for intensity correction.
+    :param division_column: Optional name of a column that the intensity is divided by after attenuator correction.
     """
 
     def __init__(self, file_path: str, angle_columns: list, intensity_column: str, wavelength: float, beam_width: float,
@@ -53,6 +54,7 @@ class SpecLoader:
     def load_scan(self, scan_number: int, trim_front: int = None, trim_back: int = None) -> ReflectivityScan:
         """Read reflectivity scan from SPEC file, trim it and return it in a ReflectivityScan object."""
         scan = self.parser.extract_scan(scan_number)
+        scan_time = self.parser.scan_info[str(scan_number)]['time']
         angles = np.array([np.array(abs(scan[column_name])) for column_name in self.angle_columns])
         scattering_angle = np.sum(np.atleast_2d(angles), axis=0)
         intensity = np.array(scan[self.intensity_column])
@@ -69,7 +71,8 @@ class SpecLoader:
             scattering_angle, intensity = self._trim_front(scattering_angle, intensity, trim_front)
 
         return ReflectivityScan(scan_number, scattering_angle, intensity, self.wavelength, **self.footprint_params,
-                                normalize_to=self.normalize_to)
+                                normalize_to=self.normalize_to,
+                                timestamp=scan_time)
 
     def load_scans(self, scan_numbers: Iterator, trim_front: int = None, trim_back: int = None) -> ScanSeries:
         """Read several reflectivity scans from SPEC file, trim them and return them in a ScanSeries object."""
