@@ -3,6 +3,10 @@ import pandas as pd
 
 
 class SpecParser:
+    """Parse individual SPEC file scans on to Pandas DataFrames.
+
+    :param file_path: File path of the SPEC file.
+    """
     def __init__(self, file_path: str):
         self._file_path = file_path
         with open(file_path) as file:
@@ -21,6 +25,7 @@ class SpecParser:
         return len(self._scan_index)
 
     def extract_scan(self, scan_number):
+        """Extract scan of a given number into a table in the form of a Pandas DataFrame."""
         column_names = self._extract_column_names(scan_number)
         data = self._extract_scan_data(scan_number)
         return pd.DataFrame(data=data, columns=column_names)
